@@ -1,5 +1,5 @@
 ;;; dtk-speak.el --- Provides Emacs Lisp interface to speech server
-;;;$Id: dtk-speak.el 7733 2012-05-03 02:12:31Z tv.raman.tv $
+;;;$Id: dtk-speak.el 8276 2013-03-30 15:19:30Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacs interface to TTS
 ;;; Keywords: Dectalk Emacs Elisp
@@ -53,7 +53,6 @@
 
 (require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
-(require 'backquote)
 (require 'custom)
 (require 'dtk-interp)
 (require 'dtk-unicode)
@@ -338,14 +337,14 @@ Optional argument FORCE  flushes the command to the speech server."
   (interactive "sEnter new language: \n")
   (declare (special dtk-quiet dtk-speaker-process
                     dtk-speak-server-initialized))
-  (when dtk-speak-server-initialized (dtk-interp-language lang (interactive-p))))
+  (when dtk-speak-server-initialized (dtk-interp-language lang (ems-interactive-p ))))
 
 (defun dtk-set-next-language ()
   "Switch to the next available language"
   (interactive)
   (declare (special dtk-speak-server-initialized))
   (when dtk-speak-server-initialized
-    (dtk-interp-next-language (interactive-p))))
+    (dtk-interp-next-language (ems-interactive-p ))))
 ;;)
 
 (defun dtk-set-previous-language ()
@@ -355,7 +354,7 @@ Optional argument FORCE  flushes the command to the speech server."
                     dtk-speak-server-initialized))
   ;;  (unless dtk-quiet
   (when dtk-speak-server-initialized
-    (dtk-interp-previous-language (interactive-p))))
+    (dtk-interp-previous-language (ems-interactive-p ))))
 ;;)
 
 (defun dtk-set-preferred-language (alias lang)
@@ -610,25 +609,24 @@ Argument COMPLEMENT  is the complement of separator."
   (unless (or (eq 'inaudible voice )
               (and (listp voice)
                    (member 'inaudible voice)))
-    (dtk-interp-queue
-     (format "%s%s %s \n"
-             (cond
-              ((symbolp voice)
-               (tts-get-voice-command
-                (if (boundp  voice )
-                    (symbol-value voice )
-                  voice)))
-              ((listp voice)
-               (mapconcat  #'(lambda (v)
-                               (tts-get-voice-command
-                                (if (boundp  v )
-                                    (symbol-value v )
-                                  v)))
-                           voice
-                           " "))
-              (t       ""))
-             text
-             tts-voice-reset-code))))
+    (dtk-interp-queue-code
+     (cond
+      ((symbolp voice)
+       (tts-get-voice-command
+        (if (boundp  voice )
+            (symbol-value voice )
+          voice)))
+      ((listp voice)
+       (mapconcat  #'(lambda (v)
+                       (tts-get-voice-command
+                        (if (boundp  v )
+                            (symbol-value v )
+                          v)))
+                   voice
+                   " "))
+      (t       "")))
+    (dtk-interp-queue text)
+    (dtk-interp-queue-code tts-voice-reset-code)))
 
 ;;;Internal function used by dtk-speak to send text out.
 ;;;Handles voice locking etc.
@@ -678,7 +676,7 @@ Arguments START and END specify region to speak."
              (get-text-property start 'auditory-icon))
     (emacspeak-queue-auditory-icon
      (get-text-property start 'auditory-icon)))
-  (dtk-interp-queue (format "%s\n" tts-voice-reset-code))
+  (dtk-interp-queue-code tts-voice-reset-code)
   (cond
    (voice-lock-mode
     (let ((last  nil)
@@ -688,13 +686,12 @@ Arguments START and END specify region to speak."
                         (next-true-single-property-change start 'personality
                                                           (current-buffer) end)))
         (if personality
-            (dtk-speak-using-voice personality
-                                   (buffer-substring start last ))
+            (dtk-speak-using-voice personality (buffer-substring start last ))
           (dtk-interp-queue (buffer-substring  start last)))
         (setq start  last
               personality
               (get-text-property last  'personality))) ; end while
-      ))                                               ; end clause
+      ))                                ; end clause
    (t (dtk-interp-queue (buffer-substring start end  )))))
 
                                         ;Force the speech.
@@ -790,7 +787,10 @@ Argument OUTPUT is the newly arrived output."
         (setq ,switch (default-value ',switch )))
        (t  (make-local-variable ',switch)
            (setq ,switch (not ,switch ))))
-      (when (interactive-p)
+      (when
+          (if (fboundp 'called-interactively-p)
+              (called-interactively-p 'interactive)
+            (interactive-p))
         (emacspeak-auditory-icon (if ,switch 'on 'off))
         (message "Turned %s %s  %s."
                  (if ,switch "on" "off" )
@@ -820,7 +820,7 @@ current local  value to the result."
       (setq dtk-speech-rate rate))
      (t (setq dtk-speech-rate rate)))
     (dtk-interp-set-rate rate)
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (message "Set speech rate to %s %s"
                rate
                (if prefix "" "locally")))))
@@ -852,7 +852,7 @@ speech rate:")))
          (+ dtk-speech-rate-base
             (* dtk-speech-rate-step  level ))
          prefix )
-        (when (interactive-p)
+        (when (ems-interactive-p )
           (message "Set speech rate to level %s"
                    level))))))
 
@@ -874,7 +874,7 @@ current local  value to the result."
      (t (make-local-variable 'dtk-character-scale)
         (setq dtk-character-scale factor)))
     (dtk-interp-set-character-scale dtk-character-scale)
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (message "Set character scale factor to %s %s"
                dtk-character-scale
                (if  prefix ""  "locally")))))
@@ -956,7 +956,7 @@ current local  value to the result."
      (t (make-local-variable 'dtk-punctuation-mode)
         (setq dtk-punctuation-mode mode )))
     (dtk-interp-set-punctuations mode)
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (message "set punctuation mode to %s %s"
                mode
                (if prefix "" "locally")))))
@@ -986,7 +986,7 @@ Interactive PREFIX arg makes the new setting global."
     (dtk-set-punctuations-to-some prefix ))
    ((eq 'some  dtk-punctuation-mode )
     (dtk-set-punctuations-to-all prefix )))
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "set punctuation mode to %s %s"
              dtk-punctuation-mode
              (if prefix "" "locally"))))
@@ -1014,7 +1014,7 @@ Typically used after the Dectalk has been power   cycled."
 
 ;;;###autoload
 (defun dtk-pause ()
-  "Temporarily pause / rsume speech."
+  "Temporarily pause / resume speech."
   (interactive)
   (declare (special dtk-paused))
   (cond
@@ -1537,6 +1537,7 @@ This is setup on a per engine basis.")
                                         ; exact match
    ((string-match "^espeak$" tts-name) (espeak-configure-tts))
    ((string-match "^eflite$" tts-name) (flite-configure-tts))
+   ((string-match "^log-server$" tts-name) t); use previous configuration
                                         ; generic configure
    (t (plain-configure-tts)))
   (when (string-match "^ssh" tts-name)  ;remote server
@@ -1566,7 +1567,7 @@ ALSA_DEFAULT to specified device before starting the server."
   (declare (special   dtk-program dtk-servers-alist
                       tts-device emacspeak-servers-directory
                       emacspeak-ssh-tts-server))
-  (when (and (interactive-p) device)
+  (when (and (ems-interactive-p ) device)
     (setq tts-device (read-from-minibuffer "ALSA_DEFAULT: ")))
   (setenv "ALSA_DEFAULT" tts-device)
   (let ((ssh-server (format "ssh-%s" dtk-program)))
@@ -1574,7 +1575,7 @@ ALSA_DEFAULT to specified device before starting the server."
     (when (file-exists-p (expand-file-name ssh-server emacspeak-servers-directory))
       (setq emacspeak-ssh-tts-server ssh-server)
       (setq-default emacspeak-ssh-tts-server ssh-server))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (dtk-initialize))))
 
 (defcustom tts-device-list (list "default")
@@ -1696,22 +1697,17 @@ Port  defaults to  dtk-local-server-port"
 (defvar dtk-speak-server-initialized nil
   "Records if the server is initialized.")
 
-(defvar dtk-speak-process-connection-type nil
-  "*Specifies if we use ptys or pipes to connect to the speech server process.
-Has the same semantics as the builtin `process-connection-type'.
-Default is to use pipes.")
-
 (defvar tts-debug-buffer " *speaker*"
   "Buffer holding speech server debug output.")
 
 (defun  dtk-initialize ()
   "Initialize speech system."
-  (declare (special dtk-program tts-debug-buffer dtk-speak-process-connection-type
+  (declare (special dtk-program tts-debug-buffer 
                     dtk-speaker-process  dtk-debug
                     dtk-speak-server-initialized
                     dtk-startup-hook emacspeak-servers-directory))
   (let ((new-process nil)
-        (process-connection-type  dtk-speak-process-connection-type))
+        (process-connection-type  nil))
     (setq new-process
           (start-process
            "speaker"
@@ -1732,7 +1728,7 @@ Default is to use pipes.")
       (set-process-coding-system dtk-speaker-process 'utf-8 'utf-8)
       (run-hooks 'dtk-startup-hook ))
      (t
-      (when (interactive-p)
+      (when (ems-interactive-p )
         (message "The speech server is not running."))))))
 ;;;###autoload
 (defun tts-restart ()
@@ -1770,10 +1766,10 @@ since the synthesizer is getting a word at a time."
   (cond
    ((not (string-match " " dtk-chunk-separator-syntax))
     (dtk-chunk-on-white-space-and-punctuations)
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (message "Text will be split at punctuations and white space when speaking") ))
    (t (dtk-chunk-only-on-punctuations)
-      (when (interactive-p)
+      (when (ems-interactive-p )
         (message "Text split  at clause boundaries")))))
 
 ;;;###autoload
@@ -1788,7 +1784,7 @@ Argument S specifies the syntax class."
     (read-from-minibuffer "Specify separator syntax string: ")))
   (declare (special dtk-chunk-separator-syntax))
   (setq dtk-chunk-separator-syntax s)
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Set  separator to %s" s)))
 
 ;;}}}
@@ -1898,6 +1894,12 @@ only speak upto the first ctrl-m."
              (dtk-format-text-and-speak start (point-max)))))
     (dtk-force)))
 
+(defsubst dtk-speak-and-echo (message)
+  "Speak message and echo it to the message area."
+  (let ((emacspeak-speak-messages nil))
+    (dtk-speak message) 
+    (message message)))
+
 (defun dtk-speak-list (text &optional group-count)
   "Speak a  list of strings.
 Argument TEXT  is the list of strings to speak.
@@ -1956,7 +1958,7 @@ Optional argument group-count specifies grouping for intonation."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
