@@ -6,7 +6,7 @@
 ;;; Using patch from Lukas.
 ;;
 ;; Author: Lukas Loehrer <loehrerl |at| gmx.net>
-;; Version: $Id: dtk-unicode.el 7734 2012-05-03 02:20:29Z tv.raman.tv $
+;; Version: $Id: dtk-unicode.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;; Keywords:  TTS, Unicode
 
 ;;}}}
@@ -110,8 +110,6 @@ themselves, e.g., when using an Asian language."
   :type 'boolean
   :group 'dtk-unicode)
 
-  
-
 (defcustom dtk-unicode-name-transformation-rules-alist
   '(
     ("^greek\\( small\\| capital\\)? letter \\(.*\\)$" .  (lambda (s) (match-string 2 s)))
@@ -207,7 +205,7 @@ charsets returned by operations such as `find-charset-region'."
 (defvar dtk-unicode-cache (make-hash-table)
   "Cache for unicode data lookups.")
 
-(defadvice describe-char-unicode-data (around dtk-unicode pre act)
+(defadvice describe-char-unicode-data (around emacspeak pre act comp)
   "Cache result."
   (let* ((char (ad-get-arg 0))
          (result (gethash char dtk-unicode-cache 'not-found)))
@@ -223,7 +221,7 @@ charsets returned by operations such as `find-charset-region'."
 Converts char to unicode if necessary (for emacs 22)."
   (let ((unicode (encode-char char 'ucs)))
     (and unicode (condition-case nil
-                     (let ((emacspeak-speak-cue-errors nil)
+                     (let ((emacspeak-speak-errors nil)
                            (emacspeak-speak-messages nil))
                        (describe-char-unicode-data unicode))
                    (error nil)))))
@@ -236,8 +234,8 @@ Converts char to unicode if necessary (for emacs 22)."
   "Return unicode name for character CHAR.
 nil if CHAR is not in Unicode."
   (downcase
-   (or (cadar (describe-char-unicode-data char))
-       (car (rassoc char (ucs-names)))
+   (or (car (rassoc char (ucs-names)))
+       (cadar (describe-char-unicode-data char))
        "")))
 
 (defsubst dtk-unicode-char-punctuation-p (char)
@@ -336,7 +334,7 @@ Does nothing for unibyte buffers."
 ;;; local variables:
 ;;; coding: utf-8
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
