@@ -54,7 +54,9 @@
 (require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
+(require 'browse-url)
 (require 'emacspeak-webutils)
+(require 'emacspeak-xslt)
 (require 'xml-parse)
 (require 'xml)
 (require 'derived)
@@ -89,6 +91,24 @@
   "Customize this to the root of where books are organized."
   :type 'directory
   :group 'emacspeak-bookshare)
+;;;###autoload
+(defcustom emacspeak-bookshare-browser-function
+  'browse-url-w3
+  "Function to display Bookshare Book content in a WWW browser.
+This is used by the various Bookshare view commands to display
+  content from Daisy books."
+  :type '(choice
+          (function-item :tag "Emacs W3" :value  browse-url-w3)
+          (function-item :tag "Mozilla" :value  browse-url-mozilla)
+          (function-item :tag "Firefox" :value browse-url-firefox)
+          (function-item :tag "Chromium" :value browse-url-chromium)
+          (function-item :tag "Text browser in an Emacs window"
+                         :value browse-url-text-emacs)
+          (function-item :tag "Default Mac OS X browser"
+                         :value browse-url-default-macosx-browser)
+          (function :tag "Your own function"))
+  :version "37"
+  :group 'emacspeak-bookshare)
 
 ;;}}}
 ;;{{{ XML Compatibility:
@@ -498,7 +518,7 @@ The Emacspeak Bookshare front-end is launched by command
 emacspeak-bookshare bound to \\[emacspeak-bookshare]
 
 This command switches to a special buffer that has Bookshare
-commands bounds to single keystrokes-- see the ke-binding list at
+commands bounds to single keystrokes-- see the key-binding list at
 the end of this description. Use Emacs online help facility to
 look up help on these commands.
 
@@ -1062,8 +1082,9 @@ Make sure it's downloaded and unpacked first."
          (directory-files directory 'full ".xml"))))))))
 
 (defun emacspeak-bookshare-extract-xml (url)
-  "Extract content refered to by link under point, and return an XML buffer."
+  "Extract content referred to by link under point, and return an XML buffer."
   (interactive "sURL: ")
+  (declare (special  emacspeak-we-xsl-filter))
   (let ((fields (split-string url "#"))
         (id nil)
         (url nil))
@@ -1078,9 +1099,11 @@ Make sure it's downloaded and unpacked first."
       (format "//*[@id=\"%s\"]" id) url))))
 
 (defun emacspeak-bookshare-extract-and-view (url)
-  "Extract content refered to by link under point, and render via the browser."
+  "Extract content referred to by link under point, and render via the browser."
   (interactive "sURL: ")
-  (let ((result (emacspeak-bookshare-extract-xml url)))
+  (declare (special emacspeak-bookshare-browser-function))
+  (let ((result (emacspeak-bookshare-extract-xml url))
+        (browse-url-browser-function emacspeak-bookshare-browser-function))
     (save-excursion
       (set-buffer result)
       (emacspeak-webutils-autospeak)
@@ -1089,6 +1112,7 @@ Make sure it's downloaded and unpacked first."
 (defun emacspeak-bookshare-view-page-range (url )
   "Play pages in specified page range from URL."
   (interactive "sURL:")
+  (declare (special emacspeak-bookshare-browser-function))
   (let* ((start (read-from-minibuffer "Start Page: "))
          (end (read-from-minibuffer "End Page: "))
          (result
@@ -1097,7 +1121,8 @@ Make sure it's downloaded and unpacked first."
            (substring url 7)
            (list
             (cons "start" (format "'%s'" start ))
-            (cons "end" (format "'%s'" end ))))))
+            (cons "end" (format "'%s'" end )))))
+         (browse-url-browser-function emacspeak-bookshare-browser-function))
     (save-excursion
       (set-buffer result)
       (emacspeak-webutils-autospeak)
@@ -1149,40 +1174,42 @@ Make sure it's downloaded and unpacked first."
   :type '(choice
           (const :tag "lynx"  "lynx -dump -stdin")
           (const "html2text" "html2text"))
-  :group 'emacspeak-bookshare)(defun emacspeak-bookshare-fulltext (directory)
-                                "Display fulltext contents of  book in specified directory.
+  :group 'emacspeak-bookshare)
+(defun emacspeak-bookshare-fulltext (directory)
+  "Display fulltext contents of  book in specified directory.
 Useful for fulltext search in a book."
-                                (interactive
-                                 (list
-                                  (or (emacspeak-bookshare-get-directory)
-                                      (let ((completion-ignore-case t)
-                                            (emacspeak-speak-messages nil)
-                                            (read-file-name-completion-ignore-case t))
-                                        (read-directory-name "Book: "
-                                                             (when (eq major-mode 'dired-mode) (dired-get-filename))
-                                                             emacspeak-bookshare-directory)))))
-                                (declare (special emacspeak-bookshare-html-to-text-command
-                                                  emacspeak-bookshare-directory))
-                                (let ((xsl (emacspeak-bookshare-xslt directory))
-                                      (buffer (get-buffer-create "Full Text"))
-                                      (command nil)
-                                      (inhibit-read-only t))
-                                  (with-current-buffer buffer
-                                    (setq command
-                                          (format
-                                           "%s  --nonet --novalid %s %s | %s"
-                                           emacspeak-xslt-program xsl
-                                           (shell-quote-argument
-                                            (first (directory-files directory 'full ".xml")))
-                                           emacspeak-bookshare-html-to-text-command))
-                                    (erase-buffer)
-                                    (setq buffer-undo-list t)
-                                    (shell-command command (current-buffer) nil)
-                                    (setq buffer-read-only t)
-                                    (goto-char (point-min)))
-                                  (switch-to-buffer buffer)
-                                  (emacspeak-auditory-icon 'open-object)
-                                  (emacspeak-speak-mode-line)))
+  (interactive
+   (list
+    (or (emacspeak-bookshare-get-directory)
+        (let ((completion-ignore-case t)
+              (emacspeak-speak-messages nil)
+              (read-file-name-completion-ignore-case t))
+          (read-directory-name "Book: "
+                               (when (eq major-mode 'dired-mode) (dired-get-filename))
+                               emacspeak-bookshare-directory)))))
+  (declare (special emacspeak-xslt-program))
+  (declare (special emacspeak-bookshare-html-to-text-command
+                    emacspeak-bookshare-directory))
+  (let ((xsl (emacspeak-bookshare-xslt directory))
+        (buffer (get-buffer-create "Full Text"))
+        (command nil)
+        (inhibit-read-only t))
+    (with-current-buffer buffer
+      (setq command
+            (format
+             "%s  --nonet --novalid %s %s | %s"
+             emacspeak-xslt-program xsl
+             (shell-quote-argument
+              (first (directory-files directory 'full ".xml")))
+             emacspeak-bookshare-html-to-text-command))
+      (erase-buffer)
+      (setq buffer-undo-list t)
+      (shell-command command (current-buffer) nil)
+      (setq buffer-read-only t)
+      (goto-char (point-min)))
+    (switch-to-buffer buffer)
+    (emacspeak-auditory-icon 'open-object)
+    (emacspeak-speak-mode-line)))
 
 (defun emacspeak-bookshare-sign-out ()
   "Sign out, clearing password."
@@ -1228,7 +1255,7 @@ Useful for fulltext search in a book."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
