@@ -1,5 +1,5 @@
 ;;; emacspeak-bs.el --- speech-enable bs buffer selection
-;;; $Id: emacspeak-bs.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; $Id: emacspeak-bs.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:   extension to speech enable bs
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -123,119 +123,119 @@
 
 (defadvice bs-kill (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice bs-abort (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 (defadvice bs-set-configuration-and-refresh (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)))
 (defadvice bs-refresh (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)))
 
 (defadvice bs-view (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 (defadvice bs-select (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 (defadvice bs-select-other-window (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice bs-tmp-select-other-window (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice bs-select-other-frame (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice bs-select-in-one-window (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice bs-bury-buffer (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 (defadvice bs-save (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'save-object)))
 (defadvice bs-toggle-current-to-show (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'button)
     (emacspeak-bs-speak-buffer-line)))
 (defadvice bs-set-current-buffer-to-show-never (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'button)
     (emacspeak-bs-speak-buffer-line)))
 (defadvice bs-mark-current (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'mark-object)
     (emacspeak-bs-speak-buffer-line)))
 (defadvice bs-unmark-current (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'deselect-object)
     (emacspeak-bs-speak-buffer-line)))
 
 (defadvice bs-delete (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-bs-speak-buffer-line)))
 (defadvice bs-delete-backward (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-bs-speak-buffer-line)))
 
 (defadvice bs-up (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-bs-speak-buffer-line)))
 (defadvice bs-down (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-bs-speak-buffer-line)))
 
 (defadvice bs-cycle-next (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((emacspeak-speak-messages nil))
       (emacspeak-auditory-icon 'select-object)
       (emacspeak-speak-mode-line))))
 
 (defadvice bs-cycle-previous (after emacspeak pre act comp)
   "Speech-enable bs mode"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((emacspeak-speak-messages nil))
       (emacspeak-auditory-icon 'select-object)
       (emacspeak-speak-mode-line))))
@@ -247,7 +247,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
