@@ -1,5 +1,5 @@
 ;;; emacspeak-buff-menu.el --- Speech enable Buffer Menu Mode -- used to manage buffers
-;;; $Id: emacspeak-buff-menu.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; $Id: emacspeak-buff-menu.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to buff-menu
 ;;; Keywords: Emacspeak, Speak, Spoken Output, buff-menu
@@ -132,7 +132,7 @@
 (defadvice list-buffers (after emacspeak pre act )
   "Provide auditory feedback"
   (declare (special Buffer-menu-mode-map))
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (other-window 1)
     (goto-char (point-min))
     (forward-line 2)
@@ -146,78 +146,78 @@
 
 (defadvice buffer-menu (after emacspeak pre act )
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'task-done)
     (message "Displayed list of buffers in other window")))
 
 ;;{{{  buffer manipulation commands 
 (defadvice Buffer-menu-bury (after emacspeak pre act)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-list-buffers-speak-buffer-line )))
 
 (defadvice Buffer-menu-delete-backwards (after emacspeak pre act)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-list-buffers-speak-buffer-line )))
 
 (defadvice Buffer-menu-delete (after emacspeak pre act)
   "Provide spoken and auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-list-buffers-speak-buffer-line )))
 
 (defadvice Buffer-menu-mark (after emacspeak pre act)
   "Provide spoken and auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'mark-object)
     (emacspeak-list-buffers-speak-buffer-line )))
 
 (defadvice Buffer-menu-quit (after emacspeak pre act)
   "Speak the modeline of the newly visible buffer."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice Buffer-menu-save (after emacspeak pre act)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'save-object)
     (emacspeak-list-buffers-speak-buffer-line )))
 
 (defadvice Buffer-menu-select (after emacspeak pre act)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line )))
 
 (defadvice Buffer-menu-unmark (after emacspeak pre act)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'deselect-object)
     (emacspeak-list-buffers-speak-buffer-line )))
 
 (defadvice Buffer-menu-backup-unmark (after emacspeak pre act)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'deselect-object)
     (emacspeak-list-buffers-speak-buffer-line )))
 
 (defadvice Buffer-menu-execute (after emacspeak pre act )
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'task-done)))
 
 (defadvice Buffer-menu-toggle-read-only (after emacspeak pre act )
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-list-buffers-speak-buffer-line )))
 
 (defadvice Buffer-menu-not-modified (after emacspeak pre act )
   "Provide auditory feedback "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-list-buffers-speak-buffer-line)
     (if (ad-get-arg 0)
         (emacspeak-auditory-icon 'modified-object )
@@ -225,7 +225,7 @@
 
 (defadvice Buffer-menu-visit-tags-table (before emacspeak pre act )
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Visiting tags table on current line")))
 
 ;;}}}
@@ -233,24 +233,24 @@
 
 (defadvice Buffer-menu-1-window (after emacspeak pre act)
   "Announce the newly selected buffer."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-speak-mode-line )
     (emacspeak-auditory-icon 'select-object)))
 
 (defadvice Buffer-menu-2-window (after emacspeak pre act)
   "Announce the newly selected buffer."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-speak-mode-line )
     (emacspeak-auditory-icon 'select-object)))
 
 (defadvice Buffer-menu-this-window (after emacspeak pre act)
   "Announce the newly selected buffer."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-speak-mode-line )
     (emacspeak-auditory-icon 'select-object)))
 (defadvice Buffer-menu-other-window (after emacspeak pre act)
   "Provide auditory feedback"
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
@@ -262,7 +262,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
