@@ -2,85 +2,84 @@
 ;;
 ;;; Code:
 
-(put 'emacspeak-speak 'custom-loads '(emacspeak-speak emacspeak-wizards emacspeak-advice))
-(put 'emacspeak-pronounce 'custom-loads '(emacspeak-pronounce))
-(put 'emacspeak-eperiodic 'custom-loads '(emacspeak-eperiodic))
-(put 'emacspeak-ediff 'custom-loads '(emacspeak-ediff))
-(put 'emacspeak-ocr 'custom-loads '(emacspeak-ocr))
 (put 'tts 'custom-loads '(emacspeak-setup dtk-speak))
-(put 'emacspeak-calendar 'custom-loads '(emacspeak-calendar))
-(put 'emacspeak-dismal 'custom-loads '(emacspeak-dismal))
-(put 'emacspeak-bookshare 'custom-loads '(emacspeak-bookshare))
 (put 'games 'custom-loads '(tetris))
+(put 'emacspeak-madplay 'custom-loads '(emacspeak-madplay))
+(put 'emacspeak-webutils 'custom-loads '(emacspeak-webutils))
+(put 'emacspeak-jabber 'custom-loads '(emacspeak-jabber))
+(put 'emacspeak-webspace 'custom-loads '(emacspeak-webspace))
+(put 'emacspeak-custom 'custom-loads '(emacspeak-custom))
+(put 'emacspeak-gnus 'custom-loads '(emacspeak-gnus))
+(put 'flyspell 'custom-loads '(emacspeak-flyspell))
+(put 'emacspeak-org 'custom-loads '(emacspeak-org))
+(put 'voice-fonts 'custom-loads '(voice-setup))
+(put 'emacspeak 'custom-loads '(dtk-unicode emacspeak-add-log emacspeak-alsaplayer emacspeak-keymap emacspeak-webutils emacspeak-aumix emacspeak-bookshare emacspeak-daisy emacspeak-dbus emacspeak-dismal emacspeak-ediff emacspeak-wizards emacspeak-epub emacspeak-erc emacspeak-eshell emacspeak-eterm emacspeak-eudc emacspeak-flyspell emacspeak-forms emacspeak-gnus emacspeak-ido emacspeak-ispell emacspeak-kite emacspeak-librivox emacspeak-m-player emacspeak emacspeak-message emacspeak-midge emacspeak-moz emacspeak-npr emacspeak-nxml emacspeak-ocr emacspeak-pronounce emacspeak-replace emacspeak-speak emacspeak-sounds emacspeak-advice emacspeak-speedbar emacspeak-table-ui emacspeak-vm emacspeak-w3 emacspeak-w3m emacspeak-we emacspeak-websearch emacspeak-widget emacspeak-xml-shell emacspeak-xslt dtk-speak voice-setup))
+(put 'emacspeak-alsaplayer 'custom-loads '(emacspeak-alsaplayer))
+(put 'w3m 'custom-loads '(emacspeak-w3m))
+(put 'emacspeak-epub 'custom-loads '(emacspeak-epub))
+(put 'emacspeak-table 'custom-loads '(emacspeak-table-ui))
+(put 'eudc 'custom-loads '(emacspeak-eudc))
+(put 'emacspeak-aumix 'custom-loads '(emacspeak-aumix))
+(put 'emacspeak-speedbar 'custom-loads '(emacspeak-speedbar))
+(put 'emacspeak-imenu 'custom-loads '(emacspeak-imenu))
+(put 'emacspeak-xml-shell 'custom-loads '(emacspeak-xml-shell))
+(put 'emacspeak-xslt 'custom-loads '(emacspeak-xslt))
+(put 'emacspeak-dbus 'custom-loads '(nm))
+(put 'emacspeak-ocr 'custom-loads '(emacspeak-ocr))
+(put 'emacspeak-websearch 'custom-loads '(emacspeak-websearch))
+(put 'accessibility 'custom-loads '(emacspeak))
+(put 'emacspeak-message 'custom-loads '(emacspeak-message))
+(put 'emacspeak-outline 'custom-loads '(emacspeak-outline))
 (put 'emacspeak-npr 'custom-loads '(emacspeak-npr))
 (put 'emacspeak-tnt 'custom-loads '(emacspeak-tnt))
-(put 'emacspeak-madplay 'custom-loads '(emacspeak-madplay))
-(put 'emacspeak-jabber 'custom-loads '(emacspeak-jabber))
-(put 'emacspeak-w3m 'custom-loads '(emacspeak-w3m))
-(put 'emacspeak-custom 'custom-loads '(emacspeak-custom))
-(put 'emacspeak-eterm 'custom-loads '(emacspeak-eterm))
-(put 'w3m 'custom-loads '(emacspeak-w3m))
-(put 'dtk-unicode 'custom-loads '(dtk-unicode))
-(put 'emacspeak-forms 'custom-loads '(emacspeak-forms))
-(put 'emacspeak-gnus 'custom-loads '(emacspeak-gnus))
-(put 'eudc 'custom-loads '(emacspeak-eudc))
-(put 'speedbar 'custom-loads '(emacspeak-speedbar))
-(put 'emacspeak-websearch 'custom-loads '(emacspeak-websearch))
-(put 'emacspeak-midge 'custom-loads '(emacspeak-midge))
-(put 'emacspeak-dired 'custom-loads '(emacspeak-dired))
-(put 'emacspeak-xsl 'custom-loads '(emacspeak-webutils))
-(put 'emacspeak-epub 'custom-loads '(emacspeak-epub))
-(put 'emacspeak-rss 'custom-loads '(emacspeak-webutils))
-(put 'emacspeak-message 'custom-loads '(emacspeak-message))
-(put 'cd-tool 'custom-loads '(cd-tool))
-(put 'emacspeak-outline 'custom-loads '(emacspeak-outline))
-(put 'emacspeak-daisy 'custom-loads '(emacspeak-daisy))
-(put 'emacspeak-xslt 'custom-loads '(emacspeak-xslt))
 (put 'emacspeak-eshell 'custom-loads '(emacspeak-eshell))
-(put 'emacspeak-dbus 'custom-loads '(nm))
-(put 'emacspeak-webutils 'custom-loads '(emacspeak-webutils))
-(put 'emacspeak-alsaplayer 'custom-loads '(emacspeak-alsaplayer))
-(put 'flyspell 'custom-loads '(emacspeak-flyspell))
-(put 'emacspeak-webspace 'custom-loads '(emacspeak-webspace))
+(put 'emacspeak-pronounce 'custom-loads '(emacspeak-pronounce))
 (put 'emacspeak-librivox 'custom-loads '(emacspeak-librivox))
-(put 'emacspeak-xml-shell 'custom-loads '(emacspeak-xml-shell))
-(put 'voice-fonts 'custom-loads '(voice-setup))
-(put 'forms 'custom-loads '(emacspeak-forms))
+(put 'cd-tool 'custom-loads '(cd-tool))
 (put 'emacspeak-m-player 'custom-loads '(emacspeak-m-player))
-(put 'emacspeak-spek 'custom-loads '(emacspeak-advice))
-(put 'accessibility 'custom-loads '(emacspeak))
 (put 'emacspeak-atom 'custom-loads '(emacspeak-webutils))
-(put 'applications 'custom-loads '(emacspeak))
-(put 'emacspeak-erc 'custom-loads '(emacspeak-erc))
+(put 'emacspeak-w3m 'custom-loads '(emacspeak-w3m))
 (put 'emacspeak-hide 'custom-loads '(emacspeak-hide))
-(put 'emacspeak 'custom-loads '(dtk-unicode emacspeak-add-log emacspeak-alsaplayer emacspeak-keymap emacspeak-webutils emacspeak-aumix emacspeak-bookshare emacspeak-daisy emacspeak-dbus emacspeak-dismal emacspeak-ediff emacspeak-wizards emacspeak-epub emacspeak-erc emacspeak-eshell emacspeak-eterm emacspeak-eudc emacspeak-flyspell emacspeak-forms emacspeak-gnus emacspeak-ido emacspeak-ispell emacspeak-librivox emacspeak-m-player emacspeak emacspeak-message emacspeak-midge emacspeak-moz emacspeak-npr emacspeak-nxml emacspeak-ocr emacspeak-pronounce emacspeak-replace emacspeak-speak emacspeak-sounds emacspeak-speedbar emacspeak-table-ui emacspeak-vm emacspeak-w3 emacspeak-w3m emacspeak-we emacspeak-websearch emacspeak-widget emacspeak-xml-shell emacspeak-xslt dtk-speak voice-setup))
-(put 'message 'custom-loads '(emacspeak-message))
-(put 'emacspeak-speedbar 'custom-loads '(emacspeak-speedbar))
-(put 'vm 'custom-loads '(emacspeak-vm))
+(put 'forms 'custom-loads '(emacspeak-forms))
 (put 'emacspeak-eudc 'custom-loads '(emacspeak-eudc))
-(put 'emacspeak-table 'custom-loads '(emacspeak-table-ui))
-(put 'w3 'custom-loads '(emacspeak-w3))
-(put 'emacspeak-url-template 'custom-loads '(emacspeak-url-template))
+(put 'emacspeak-speak 'custom-loads '(emacspeak-speak emacspeak-wizards emacspeak-advice))
+(put 'emacspeak-bookshare 'custom-loads '(emacspeak-bookshare))
+(put 'emacspeak-ediff 'custom-loads '(emacspeak-ediff))
+(put 'emacspeak-xsl 'custom-loads '(emacspeak-webutils))
+(put 'emacspeak-rss 'custom-loads '(emacspeak-webutils))
 (put 'emacspeak-xslide 'custom-loads '(emacspeak-xslide))
-(put 'emacspeak-aumix 'custom-loads '(emacspeak-aumix))
-(put 'emacspeak-imenu 'custom-loads '(emacspeak-imenu))
+(put 'message 'custom-loads '(emacspeak-message))
 (put 'emacspeak-we 'custom-loads '(emacspeak-we))
 (put 'emacspeak-vm 'custom-loads '(emacspeak-vm))
-(put 'dtk 'custom-loads '(dtk-speak))
-(put 'emacspeak-sounds 'custom-loads '(emacspeak-sounds))
 (put 'emacspeak-w3 'custom-loads '(emacspeak-w3))
+(put 'vm 'custom-loads '(emacspeak-vm))
+(put 'emacspeak-sounds 'custom-loads '(emacspeak-sounds))
+(put 'w3 'custom-loads '(emacspeak-w3))
+(put 'emacspeak-url-template 'custom-loads '(emacspeak-url-template))
+(put 'speedbar 'custom-loads '(emacspeak-speedbar))
+(put 'emacspeak-remote 'custom-loads '(emacspeak-remote))
+(put 'emacspeak-personality 'custom-loads '(emacspeak-personality))
+(put 'emacspeak-eterm 'custom-loads '(emacspeak-eterm))
+(put 'dtk 'custom-loads '(dtk-speak))
 (put 'widget 'custom-loads '(emacspeak-widget))
 (put 'eshell 'custom-loads '(emacspeak-eshell))
-(put 'emacspeak-remote 'custom-loads '(emacspeak-remote))
-(put 'gnus 'custom-loads '(emacspeak-gnus))
-(put 'tetris 'custom-loads '(tetris))
-(put 'emacspeak-org 'custom-loads '(emacspeak-org))
+(put 'emacspeak-forms 'custom-loads '(emacspeak-forms))
 (put 'emacspeak-ispell 'custom-loads '(emacspeak-ispell))
-(put 'isearch 'custom-loads '(emacspeak-replace))
-(put 'emacspeak-personality 'custom-loads '(emacspeak-personality))
-(put 'emacspeak-piglets 'custom-loads '(emacspeak-piglets))
-(put 'emacspeak-wizards 'custom-loads '(emacspeak-wizards))
+(put 'gnus 'custom-loads '(emacspeak-gnus))
+(put 'emacspeak-erc 'custom-loads '(emacspeak-erc))
+(put 'emacspeak-eperiodic 'custom-loads '(emacspeak-eperiodic))
+(put 'tetris 'custom-loads '(tetris))
 (put 'emacspeak-info 'custom-loads '(emacspeak-info))
+(put 'applications 'custom-loads '(emacspeak))
+(put 'emacspeak-calendar 'custom-loads '(emacspeak-calendar))
+(put 'emacspeak-midge 'custom-loads '(emacspeak-midge))
+(put 'emacspeak-dired 'custom-loads '(emacspeak-dired))
+(put 'isearch 'custom-loads '(emacspeak-replace))
+(put 'emacspeak-piglets 'custom-loads '(emacspeak-piglets))
+(put 'dtk-unicode 'custom-loads '(dtk-unicode))
+(put 'emacspeak-wizards 'custom-loads '(emacspeak-wizards))
+(put 'emacspeak-daisy 'custom-loads '(emacspeak-daisy))
+(put 'emacspeak-dismal 'custom-loads '(emacspeak-dismal))
 ;; These are for handling :version.  We need to have a minimum of
 ;; information so `customize-changed-options' could do its job.
 
@@ -103,7 +102,7 @@
      (put ,symbol ,propname ,value)))
 
 
-(defvar custom-versions-load-alist nil
+(defvar custom-versions-load-alist '(("37.0" emacspeak-advice) ("37" emacspeak-bookshare))
  "For internal use by custom.")
 
 (provide 'cus-load)
