@@ -1,5 +1,5 @@
 ;;; emacspeak-fix-interactive.el --- Tools to make  Emacs' builtin prompts   speak
-;;; $Id: emacspeak-fix-interactive.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; $Id: emacspeak-fix-interactive.el 8273 2013-03-29 15:41:45Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Fixes functions that use interactive to prompt for args.
 ;;; Approach suggested by hans@cs.buffalo.edu
@@ -72,8 +72,8 @@
    "\\|^face\\|^frame\\|^font"
    "\\|^color\\|^timer")
   "Regular expression matching function names whose interactive spec should not be fixed.")
-
-(defsubst emacspeak-should-i-fix-interactive-p (sym)
+;;;###autoload
+(defsubst emacspeak-should-i-fix-interactive-p  (sym)
   "Predicate to test if this function should be fixed. "
   (declare (special emacspeak-commands-dont-fix-regexp))
   (and
@@ -145,14 +145,14 @@ use the minibuffer."
       ;; cannot handle automatically -- tell developer
       ;; since subsequent prompts use earlier args e.g.global-set-key
       (push sym emacspeak-fix-interactive-problematic-functions)
-      (message "Not auto-advicing %s" sym))))
+      (message "Not auto-advising %s" sym))))
   t)
 
 ;;; inline function for use from other modules:
 
 (defun  emacspeak-fix-interactive-command-if-necessary (command)
   "Fix command if necessary."
-  (when (emacspeak-should-i-fix-interactive-p command)
+  (when (emacspeak-should-i-fix-interactive-p  command)
     (emacspeak-fix-interactive command)))
 
 ;;}}}
@@ -175,7 +175,7 @@ use the minibuffer."
          (commandp (cdr item))
          (emacspeak-fix-interactive-command-if-necessary (cdr
                                                           item))))
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Fixed interactive commands defined in module %s" module)))
 
 (defvar emacspeak-load-history-pointer nil
@@ -197,12 +197,12 @@ Memoizes call in emacspeak-load-history-pointer to memoize this call. "
                   (not (eq lh emacspeak-load-history-pointer)))
 ;;; fix commands in this module
         (emacspeak-fix-commands-loaded-from lh)
-        (when (interactive-p)
+        (when (ems-interactive-p )
           (message "Fixed commands in %s" (first (first lh))))
         (setq lh (rest lh)))
 ;;;memoize for future call
       (setq emacspeak-load-history-pointer load-history))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (message "Fixed recently defined  interactive commands")))
   t)
 
@@ -211,7 +211,7 @@ Memoizes call in emacspeak-load-history-pointer to memoize this call. "
 ;;{{{  end of file
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
