@@ -1,5 +1,5 @@
 ;;; emacspeak-forms.el --- Speech enable Emacs' forms mode  -- provides  a convenient database interface
-;;; $Id: emacspeak-forms.el 7323 2011-10-26 00:50:39Z tv.raman.tv $
+;;; $Id: emacspeak-forms.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; DescriptionEmacspeak extensions for forms-mode 
 ;;; Keywords:emacspeak, audio interface to emacs forms 
@@ -88,7 +88,7 @@ speak the first field")
   "Personality for read-only fields. "
   :type 'symbol
   :group 'emacspeak-forms)
-
+;;;###autoload
 (defun emacspeak-forms-speak-field ()
   "Speak current form field name and value.
 Assumes that point is at the front of a field value."
@@ -118,7 +118,7 @@ Assumes that point is at the front of a field value."
 
 (defadvice forms-next-record (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (goto-char (next-single-property-change 
                 (point)
@@ -129,7 +129,7 @@ Assumes that point is at the front of a field value."
 
 (defadvice forms-prev-record (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (goto-char (next-single-property-change 
                 (point)
@@ -140,38 +140,38 @@ Assumes that point is at the front of a field value."
 
 (defadvice forms-first-record (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-forms-summarize-current-record)))
 
 (defadvice forms-last-record (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-forms-summarize-current-record)))
 
 (defadvice forms-jump-record (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-forms-summarize-current-record)))
 
 (defadvice forms-search (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'search-hit)
     (emacspeak-forms-summarize-current-record)))
 
 (defadvice forms-exit (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice forms-next-field (around emacspeak pre act comp)
   "Provide auditory feedback."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     ad-do-it
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-forms-speak-field))
@@ -181,7 +181,7 @@ Assumes that point is at the front of a field value."
 (defadvice forms-prev-field (after emacspeak pre act comp)
   "Provide auditory feedback."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     ad-do-it
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-forms-speak-field))
@@ -190,19 +190,19 @@ Assumes that point is at the front of a field value."
 
 (defadvice forms-kill-record (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     ))
 
 (defadvice forms-insert-record (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     ))
 
 (defadvice forms-save-buffer (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when  (interactive-p)
+  (when  (ems-interactive-p )
     (emacspeak-auditory-icon 'save-object)))
 
 ;;}}}
@@ -280,7 +280,7 @@ Assumes that point is at the front of a field value."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
