@@ -1,5 +1,5 @@
 ;;; emacspeak-gnuplot.el --- speech-enable gnuplot mode
-;;; $Id: emacspeak-gnuplot.el 7323 2011-10-26 00:50:39Z tv.raman.tv $
+;;; $Id: emacspeak-gnuplot.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech-enable
 ;;; gnuplot mode
@@ -63,7 +63,7 @@
                                                  pre act
                                                  comp)
   "Speak status."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-other-window 1)))
 
@@ -71,7 +71,7 @@
                                                pre act
                                                comp)
   "Speak status."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-other-window 1)))
 
@@ -79,7 +79,7 @@
                                                 pre act
                                                 comp)
   "Speak status."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-other-window 1)))
 
@@ -87,21 +87,21 @@
                                                  pre act
                                                  comp)
   "Speak status."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-other-window 1)))
 (defadvice gnuplot-send-file-to-gnuplot (after emacspeak
                                                pre act
                                                comp)
   "Speak status."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-other-window 1)))
 
 (defadvice gnuplot-delchar-or-maybe-eof (around emacspeak pre act)
   "Speak character you're deleting."
   (cond
-   ((interactive-p )
+   ((ems-interactive-p  )
     (cond
      ((= (point) (point-max))
       (message "Sending EOF to comint process"))
@@ -114,14 +114,14 @@
 (defadvice gnuplot-kill-gnuplot-buffer (after emacspeak pre
                                               act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice gnuplot-show-gnuplot-buffer (after emacspeak pre
                                               act comp)
   "Speak status."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 
@@ -139,13 +139,13 @@
 (defadvice gnuplot-indent-line (after emacspeak pre act
                                       comp)
   "Speak line we idnented."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice gnuplot-negate-option (after emacspeak pre act comp)
   "Speak line we negated."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
@@ -160,7 +160,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
