@@ -1,5 +1,5 @@
 ;;; emacspeak-ido.el --- speech-enable ido
-;;; $Id: emacspeak-ido.el 6342 2009-10-20 19:12:40Z tv.raman.tv $
+;;; $Id: emacspeak-ido.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:   extension to speech enable ido
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2009, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -65,16 +65,14 @@
 (defvar emacspeak-ido-cache-current-directory nil
   "Cached value of ido-current-directory.")
 
-(defadvice ido-set-current-directory (before emacspeak pre act
-                                             comp)
+(defadvice ido-set-current-directory (before emacspeak pre act comp)
   "Cache previous value of ido-current-directory."
-  (setq emacspeak-ido-cache-current-directory
-        ido-current-directory))
+  (setq emacspeak-ido-cache-current-directory ido-current-directory))
 
 (defadvice ido-exhibit (after emacspeak pre act comp)
   "Speak first of the displayed matches."
   (when (and ido-matches
-             (sit-for 0.5))
+             (sit-for 0.3))
     (emacspeak-auditory-icon 'progress))
   (dtk-speak
    (concat 
@@ -95,27 +93,21 @@
 Tip: Use M-x customize to set ido-max-prospects to a small value
   when using Emacspeak --- I set it to 3.
 The default value of 12 is too high for using ido effectively with speech. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon
      (if ido-mode 'on 'off))
-    (dtk-speak
-     (format "IDo set to %s"
-             ido-mode))))
+    (dtk-speak (format "IDo set to %s" ido-mode))))
 
 (defadvice ido-everywhere (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
-    (emacspeak-auditory-icon
-     (if ido-everywhere 'on 'off))
+  (when (ems-interactive-p )
+    (emacspeak-auditory-icon (if ido-everywhere 'on 'off))
     (dtk-speak
-     (format "Turned %s IDo everywhere."
-             (if ido-everywhere " on " " off ")))))
-
- 
+     (format "Turned %s IDo everywhere." (if ido-everywhere " on " " off ")))))
 
 (defadvice ido-toggle-case (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon
      (if ido-case-fold 'on 'off))
     (dtk-speak
@@ -124,7 +116,7 @@ The default value of 12 is too high for using ido effectively with speech. "
 
 (defadvice ido-toggle-regexp (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon
      (if ido-enable-regexp 'on 'off))
     (dtk-speak
@@ -132,7 +124,7 @@ The default value of 12 is too high for using ido effectively with speech. "
              (if ido-enable-regexp 'on 'off)))))
 (defadvice ido-toggle-prefix (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon
      (if ido-enable-prefix 'on 'off))
     (dtk-speak
@@ -141,7 +133,7 @@ The default value of 12 is too high for using ido effectively with speech. "
 
 (defadvice ido-toggle-ignore (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon
      (if ido-process-ignore-lists 'on 'off))
     (dtk-speak
@@ -151,21 +143,18 @@ The default value of 12 is too high for using ido effectively with speech. "
 
 (defadvice ido-complete (after emacspeak pre act comp)
   "Speak completion at the head of the list."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (dtk-speak (car ido-matches))))
 
 (loop for f in
-      '(ido-find-file ido-find-file-other-frame
-                      ido-find-file-other-window
-                      ido-find-alternate-file
-                      ido-find-file-read-only
-                      ido-find-file-read-only-other-window ido-find-file-read-only-other-frame)
+      '(ido-find-file ido-find-file-other-frame ido-find-file-other-window
+                      ido-find-alternate-file ido-find-file-read-only ido-find-file-read-only-other-window ido-find-file-read-only-other-frame)
       do
       (eval
        `(defadvice   ,f(around emacspeak pre act comp)
           "Provide auditory feedback."
           (cond
-           ((interactive-p)
+           ((ems-interactive-p )
             (let ((emacspeak-minibuffer-enter-auditory-icon nil))
               (emacspeak-auditory-icon 'open-object)
               ad-do-it
@@ -176,14 +165,13 @@ The default value of 12 is too high for using ido effectively with speech. "
 
 (loop for f in
       '(ido-switch-buffer ido-switch-buffer-other-window
-                          ido-switch-buffer-other-frame
-                          ido-display-buffer)
+                          ido-switch-buffer-other-frame ido-display-buffer)
       do
       (eval
        `(defadvice   ,f(around emacspeak pre act comp)
           "Provide auditory feedback."
           (cond
-           ((interactive-p)
+           ((ems-interactive-p )
             (let ((emacspeak-minibuffer-enter-auditory-icon nil))
               (emacspeak-auditory-icon 'open-object)
               ad-do-it
@@ -199,29 +187,35 @@ The default value of 12 is too high for using ido effectively with speech. "
 
 (defadvice ido-next-match (after emacspeak pre act comp)
   "Speak match at the front of the list."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (dtk-speak
      (second ido-matches))))
 
 (defadvice ido-prev-match (after emacspeak pre act comp)
   "Speak match at the front of the list."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (dtk-speak
      (car (last ido-matches)))))
 
 (defadvice ido-kill-buffer-at-head (after emacspeak pre act comp)
   "Provide auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 
 (defadvice ido-kill-buffer (after emacspeak pre act comp)
   "Provide auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
+(defadvice ido-fallback-command (before emacspeak pre act comp)
+  "Provide auditory cue to indicate we are closing out the IDO   minibuffer."
+  (when (ems-interactive-p )
+    (emacspeak-auditory-icon 'close-object)
+    (emacspeak-auditory-icon 'open-object)))
+
 ;;}}}
 ;;{{{ define personalities 
 
@@ -229,14 +223,14 @@ The default value of 12 is too high for using ido effectively with speech. "
   "Emacspeak ido customizations."
   :group  'emacspeak
   )
+
 (voice-setup-add-map
  '(
    (ido-first-match voice-brighten-extra)
    (ido-only-match voice-bolden)
    (ido-subdir voice-lighten-extra)
    (ido-indicator voice-smoothen)
-   (ido-incomplete-regexp voice-monotone)
-   ))
+   (ido-incomplete-regexp voice-monotone)))
 
 ;;}}}
 ;;{{{ Additional keybindings 
@@ -253,7 +247,7 @@ The default value of 12 is too high for using ido effectively with speech. "
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
