@@ -1,5 +1,5 @@
 ;;; emacspeak-imenu.el --- Speech enable Imenu -- produce buffer-specific table of contents
-;;; $Id: emacspeak-imenu.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; $Id: emacspeak-imenu.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Auditory interface buffer indices
 ;;; Keywords: Emacspeak, Speak, Spoken Output, indices
@@ -93,7 +93,7 @@
 
 (defadvice imenu (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (ems-set-personality-temporarily (point) (1+ (point))
                                      voice-animate
                                      (emacspeak-speak-line))))
@@ -101,7 +101,7 @@
 (defadvice imenu-go-find-at-position (around emacspeak pre act comp)
   "Provide auditory feedback"
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (push-mark)
     ad-do-it
     (emacspeak-auditory-icon 'large-movement)
@@ -113,7 +113,7 @@
 
 (defadvice imenu-go--back (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (ems-set-personality-temporarily (point) (1+ (point))
                                      voice-animate
@@ -153,7 +153,7 @@
             (if (< guess target)
                 (setq target guess))))
     (goto-char target)
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-auditory-icon 'large-movement)
       (if emacspeak-imenu-autospeak
           (emacspeak-imenu-speak-this-section)
@@ -188,7 +188,7 @@
             (if (> guess target)
                 (setq target guess))))
     (goto-char target)
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-auditory-icon 'large-movement)
       (if emacspeak-imenu-autospeak
           (emacspeak-imenu-speak-this-section)
@@ -226,7 +226,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
