@@ -1,5 +1,5 @@
 ;;; emacspeak-iswitchb.el --- speech-enable iswitchb buffer selection
-;;; $Id: emacspeak-iswitchb.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; $Id: emacspeak-iswitchb.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:   extension to speech enable iswitchb
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -74,7 +74,7 @@
 
 (defadvice iswitchb-toggle-case (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon
      (if iswitchb-case 'on 'off))
     (dtk-speak
@@ -83,7 +83,7 @@
 
 (defadvice iswitchb-toggle-regexp (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon
      (if iswitchb-regexp 'on 'off))
     (dtk-speak
@@ -92,7 +92,7 @@
 
 (defadvice iswitchb-toggle-ignore (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon
      (if iswitchb-ignore 'on 'off))
     (dtk-speak
@@ -101,12 +101,12 @@
 
 (defadvice iswitchb-complete (after emacspeak pre act comp)
   "Speak completion at the head of the list."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (dtk-speak (car iswitchb-matches))))
 
 (defadvice  iswitchb-buffer (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 
@@ -117,20 +117,20 @@
 
 (defadvice iswitchb-next-match (after emacspeak pre act comp)
   "Speak match at the front of the list."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (dtk-speak
      (second iswitchb-matches))))
 
 (defadvice iswitchb-prev-match (after emacspeak pre act comp)
   "Speak match at the front of the list."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (dtk-speak
      (car (last iswitchb-matches)))))
 (defadvice iswitchb-kill-buffer (after emacspeak pre act comp)
   "Provide auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 
 ;;}}}
@@ -148,7 +148,7 @@ Place this on hook iswitchb-minibuffer-setup-hook."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
