@@ -1,5 +1,5 @@
 ;;; emacspeak-jabber.el --- Speech-Enable jabber
-;;; $Id: emacspeak-jabber.el 7225 2011-09-29 00:20:40Z tv.raman.tv $
+;;; $Id: emacspeak-jabber.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: speech-enable jabber
 ;;; Keywords: Emacspeak, jabber
@@ -106,7 +106,7 @@
 
 (defadvice jabber-activity-switch-to (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 
@@ -115,7 +115,7 @@
 
 (defadvice jabber-chat-buffer-send (after emacspeak pre act comp)
   "Produce auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 
 (loop for f in
@@ -125,7 +125,7 @@
       (eval
        `(defadvice ,f (after emacspeak pre act comp)
           "Silence keepalive messages."
-          (when (interactive-p)
+          (when (ems-interactive-p )
             (emacspeak-auditory-icon 'open-object)
             (emacspeak-speak-mode-line)))))
 
@@ -138,30 +138,30 @@
 (defadvice jabber-send-default-presence (after emacspeak pre act
                                                comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (message "Sent default presence.")))
 
 (defadvice jabber-send-away-presence (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (message "Set to be away.")))
 
 (defadvice jabber-send-xa-presence (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (message "Set extended  away.")))
 (defadvice jabber-go-to-next-jid (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice jabber-go-to-previous-jid (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
 
@@ -231,7 +231,7 @@ Returns a cons (start . end) that delimits the message."
   (let ((start nil)
         (end nil))
     (save-excursion
-      (when (interactive-p)
+      (when (ems-interactive-p )
         (unless (looking-at "^\\[")
           (re-search-backward "^\\[" nil t)))
       (setq start
@@ -281,7 +281,7 @@ session."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
