@@ -1,5 +1,5 @@
 ;;; emacspeak-midge.el --- Speech-enable MIDI editor
-;;; $Id: emacspeak-midge.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; $Id: emacspeak-midge.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech-enable MIDGE
 ;;; Keywords: Emacspeak, MIDI 
@@ -65,94 +65,94 @@
 
 (defadvice midge-indent-line(after emacspeak pre act comp)
   "Speak line after indenting it."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice midge-close-bracket(after emacspeak pre act comp)
   "Speak closing delimiter we inserted"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-this-char last-input-event)))
 
 (defadvice midge-head-block(after emacspeak pre act comp)
   "Announce insertion of head block"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (message "Started head section")))
 
 (defadvice midge-body-block(after emacspeak pre act comp)
   "Announce insertion of body block"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (message "Started body section")))
 
 (defadvice midge-repeat-block(after emacspeak pre act comp)
   "Announce insertion of repeat block"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (message "Started repeat block")))
 
 (defadvice midge-choose-block(after emacspeak pre act comp)
   "Announce insertion of choose block"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (message "Started choose block")))
 
 (defadvice midge-bend-block(after emacspeak pre act comp)
   "Announce insertion of bend block"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (message "Started bend block")))
 
 (defadvice midge-define-block(after emacspeak pre act comp)
   "Announce insertion of define block"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (message "Started define block")))
 
 (defadvice midge-repeat-line(after emacspeak pre act comp)
   "Announce insertion of repeat block"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
 
 (defadvice midge-bend-line(after emacspeak pre act comp)
   "Announce insertion of bend block"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
 
 (defadvice midge-define-line(after emacspeak pre act comp)
   "Announce insertion of define block"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
 
 (defadvice midge-choose-line(after emacspeak pre act comp)
   "Announce insertion of choose block"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
 
 (defadvice midge-compile(after emacspeak pre act comp)
   "Produce auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-message-again)))
 
 (defadvice midge-compile-debug(after emacspeak pre act comp)
   "Produce auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'task-done)))
 
 (defadvice midge-compile-verbose(after emacspeak pre act comp)
   "Produce auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'task-done)))
 
 (defadvice midge-compile-ask(after emacspeak pre act comp)
   "Produce auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'task-done)))
 
 ;;}}}
@@ -177,7 +177,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
