@@ -1,5 +1,5 @@
 ;;; emacspeak-personality.el ---Emacspeak's new personality interface
-;;; $Id: emacspeak-personality.el 7578 2012-03-17 02:52:37Z tv.raman.tv $
+;;; $Id: emacspeak-personality.el 8276 2013-03-30 15:19:30Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Voice lock implementation
 ;;; Keywords: Emacspeak,  Spoken Output, audio formatting
@@ -97,7 +97,7 @@
                  (delete-duplicates personality :test #'eq)
                personality)))
       (ems-modify-buffer-safely
-       (ad-Orig-put-text-property start end 'personality v object)))))
+       (put-text-property start end 'personality v object)))))
 
 ;;;###autoload
 (defun emacspeak-personality-append  (start end personality &optional object )
@@ -119,7 +119,7 @@ Existing personality properties on the text range are preserved."
                  start 'personality object end)))
            (cond
             ((null orig)                    ;simple case
-             (ad-Orig-put-text-property start extent 'personality v object)
+             (put-text-property start extent 'personality v object)
              (when (< extent end)
                (emacspeak-personality-append extent end v object)))
             (t                             ;accumulate the new personality
@@ -131,8 +131,8 @@ Existing personality properties on the text range are preserved."
                       (nconc
                        (if (listp orig) orig (list orig))
                        (if (listp v) v (list v)))))
-               (ad-Orig-put-text-property start extent
-                                          'personality new object))
+               (put-text-property start extent
+                                  'personality new object))
              (when (< extent end)
                (emacspeak-personality-append extent end v object)))))))
     (error nil)))
@@ -157,7 +157,7 @@ Existing personality properties on the text range are preserved."
                  start 'personality object end)))
            (cond
             ((null orig)                    ;simple case
-             (ad-Orig-put-text-property start extent 'personality v object)
+             (put-text-property start extent 'personality v object)
              (when (< extent end)
                (emacspeak-personality-prepend extent end v object)))
             (t                             ;accumulate the new personality
@@ -169,8 +169,8 @@ Existing personality properties on the text range are preserved."
                       (nconc
                        (if (listp v) v (list v))
                        (if (listp orig) orig (list orig)))))
-               (ad-Orig-put-text-property start extent
-                                          'personality new object))
+               (put-text-property start extent
+                                  'personality new object))
              (when (< extent end)
                (emacspeak-personality-prepend extent end v object)))))))
     (error nil)))
@@ -202,11 +202,11 @@ preserved."
                      (remove personality orig))
                     (t nil)))
              (if new
-                 (ad-Orig-put-text-property start extent
-                                            'personality new object)
-               (ad-Orig-remove-text-properties start extent
-                                               (list 'personality )
-                                               object))
+                 (put-text-property start extent
+                                    'personality new object)
+               (remove-text-properties start extent
+                                       (list 'personality )
+                                       object))
              (when (< extent end)
                (emacspeak-personality-remove extent end
                                              personality)))))))
@@ -219,6 +219,7 @@ preserved."
   "Check if plist contains a face setting."
   (or (memq 'face plist)
       (memq 'font-lock-face plist)))
+
 (defsubst ems-plain-cons-p (value)
   "Help identify (a . b)."
   (and (consp value)
@@ -253,45 +254,41 @@ displayed in the messages area."
 
 (defvar emacspeak-personality-unmapped-faces (make-hash-table)
   "Records faces that we have not yet mapped to personalities.")
+;;; Helper: Get face->voice mapping
+
+(defun ems-get-voice-for-face (value)
+  "Compute face->voice mapping."
+  (let ((voice nil))
+    (condition-case nil
+        (cond
+         ((symbolp value)
+          (setq voice (voice-setup-get-voice-for-face value)))
+         ((ems-plain-cons-p value)) ;;pass on plain cons
+         ( (listp value)
+           (setq voice
+                 (delq nil
+                       (mapcar   #'voice-setup-get-voice-for-face value)))))
+      (error nil))
+    voice))
 
 (defadvice put-text-property (after emacspeak-personality  pre act)
   "Used by emacspeak to augment font lock."
-  (when voice-lock-mode
+  (when (and voice-lock-mode emacspeak-personality-voiceify-faces)
     (let ((start (ad-get-arg 0))
           (end (ad-get-arg 1 ))
           (prop (ad-get-arg 2))
           (value (ad-get-arg 3 ))
           (object (ad-get-arg 4))
           (voice nil))
-      (when (and  emacspeak-personality-voiceify-faces
-                  (not (= start end))
-                  (or (eq prop 'face) (eq prop 'font-lock-face)))
-        (condition-case nil
-            (progn
-              (cond
-               ((symbolp value)
-                (setq voice (voice-setup-get-voice-for-face value)))
-               ((ems-plain-cons-p value)) ;;pass on plain cons
-               ( (listp value)
-                 (setq voice
-                       (delq nil
-                             (mapcar   #'voice-setup-get-voice-for-face value))))
-               (t (message "Got %s" value)))
-              (when voice
-                (funcall emacspeak-personality-voiceify-faces start end voice object))
-              (when (and emacspeak-personality-show-unmapped-faces
-                         (not voice))
-                (cond
-                 ((listp value)
-                  (mapcar #'(lambda (v)
-                              (puthash  v t emacspeak-personality-unmapped-faces))
-                          value))
-                 (t (puthash  value t emacspeak-personality-unmapped-faces)))))
-          (error nil))))))
+      (when (and (or (eq prop 'face) (eq prop 'font-lock-face))
+                 (not (= start end)))
+        (setq voice (ems-get-voice-for-face value))
+        (when voice
+          (funcall emacspeak-personality-voiceify-faces start end voice object))))))
 
 (defadvice add-text-properties (after emacspeak-personality  pre act)
   "Used by emacspeak to augment font lock."
-  (when voice-lock-mode
+  (when (and voice-lock-mode    emacspeak-personality-voiceify-faces)
     (let ((start (ad-get-arg 0))
           (end (ad-get-arg 1 ))
           (properties (ad-get-arg 2))
@@ -300,35 +297,14 @@ displayed in the messages area."
           (voice nil)
           (value nil))
       (setq facep (emacspeak-personality-plist-face-p properties))
-      (when (and  emacspeak-personality-voiceify-faces
-                  facep)
-        (setq value (second facep))
-        (condition-case nil
-            (progn
-              (cond
-               ((symbolp value)
-                (setq voice (voice-setup-get-voice-for-face   value)))
-               ((ems-plain-cons-p value)) ;;pass on plain cons
-               ( (listp value)
-                 (setq voice
-                       (delq nil
-                             (mapcar   #'voice-setup-get-voice-for-face value))))
-               (t (message "Got %s" value)))
-              (when voice
-                (funcall emacspeak-personality-voiceify-faces start end voice object))
-              (when (and emacspeak-personality-show-unmapped-faces
-                         (not voice))
-                (cond
-                 ((listp value)
-                  (mapcar #'(lambda (v)
-                              (puthash  v t emacspeak-personality-unmapped-faces))
-                          value))
-                 (t (puthash  value t emacspeak-personality-unmapped-faces)))))
-          (error nil))))))
+      (when facep (setq value (second facep))
+            (setq voice (ems-get-voice-for-face value))
+            (when voice
+              (funcall emacspeak-personality-voiceify-faces start end voice object))))))
 
 (defadvice set-text-properties (after emacspeak-personality  pre act)
   "Used by emacspeak to augment font lock."
-  (when voice-lock-mode
+  (when (and  voice-lock-mode emacspeak-personality-voiceify-faces)
     (let ((start (ad-get-arg 0))
           (end (ad-get-arg 1 ))
           (properties (ad-get-arg 2))
@@ -337,32 +313,12 @@ displayed in the messages area."
           (voice nil)
           (value nil))
       (setq facep (emacspeak-personality-plist-face-p properties))
-      (when (and  emacspeak-personality-voiceify-faces
-                  facep)
+      (when  facep
         (setq value (second facep))
-        (condition-case nil
-            (progn
-              (cond
-               ((symbolp value)
-                (setq voice (voice-setup-get-voice-for-face   value)))
-               ((ems-plain-cons-p value)) ;;pass on plain cons
-               ( (listp value)
-                 (setq voice
-                       (delq nil
-                             (mapcar   #'voice-setup-get-voice-for-face value))))
-               (t (message "Got %s" value)))
-              (when voice
-                (funcall emacspeak-personality-voiceify-faces start end voice object))
-              (when (and emacspeak-personality-show-unmapped-faces
-                         (not voice))
-                (cond
-                 ((listp value)
-                  (mapcar #'(lambda (v)
-                              (puthash  v t emacspeak-personality-unmapped-faces))
-                          value))
-                 (t (puthash  value t emacspeak-personality-unmapped-faces))))
-              )
-          (error nil))))))
+        (setq voice (ems-get-voice-for-face value))
+        
+        (when voice
+          (funcall emacspeak-personality-voiceify-faces start end voice object))))))
 
 (defadvice propertize (around emacspeak-personality  pre act)
   "Used by emacspeak to augment font lock."
@@ -374,47 +330,28 @@ displayed in the messages area."
     (setq facep (emacspeak-personality-plist-face-p properties))
     (cond
      ((and  emacspeak-personality-voiceify-faces
-            facep)
+            voice-lock-mode facep)
       ad-do-it
       (setq value (second facep))
-      (condition-case nil
-          (progn
-            (cond
-             ((symbolp value)
-              (setq voice (voice-setup-get-voice-for-face   value)))
-             ( (listp value)
-               (setq voice
-                     (delq nil
-                           (mapcar   #'voice-setup-get-voice-for-face value))))
-             (t (message "Got %s" value)))
-            (when voice
-              (funcall emacspeak-personality-voiceify-faces 0
-                       (length ad-return-value) voice ad-return-value))
-            (when (and emacspeak-personality-show-unmapped-faces
-                       (not voice))
-              (cond
-               ((listp value)
-                (mapcar #'(lambda (v)
-                            (puthash  v t emacspeak-personality-unmapped-faces))
-                        value))
-               (t (puthash  value t emacspeak-personality-unmapped-faces)))))
-        (error nil)))
+      (setq voice (ems-get-voice-for-face value))
+      (when voice
+        (funcall emacspeak-personality-voiceify-faces 0
+                 (length ad-return-value) voice ad-return-value)))
      (t ad-do-it))
     ad-return-value))
 
+;;; If a face property is being removed, set personality  to nil:
+
 (defadvice remove-text-properties (before emacspeak-personality pre act comp)
   "Undo any voiceification if needed."
   (when voice-lock-mode
     (let  ((start (ad-get-arg 0))
            (end (ad-get-arg 1))
            (props (ad-get-arg 2))
-           (object (ad-get-arg 3))
-           (voice nil)
-           (face nil))
+           (object (ad-get-arg 3)))
       (when (and (not (= start end))
-                 (emacspeak-personality-plist-face-p props) ) ;;; simple minded for now
-        (ad-Orig-put-text-property start end
-                                   'personality nil object)))))
+                 (emacspeak-personality-plist-face-p props)) ;;; simple minded for now
+        (put-text-property start end 'personality nil object)))))
 
 (defadvice remove-list-of-text-properties (before emacspeak-personality pre act comp)
   "Undo any voiceification if needed."
@@ -422,11 +359,9 @@ displayed in the messages area."
     (let  ((start (ad-get-arg 0))
            (end (ad-get-arg 1))
            (props (ad-get-arg 2))
-           (object (ad-get-arg 3))
-           (voice nil)
-           (face nil))
+           (object (ad-get-arg 3)))
       (when (and (not (= start end))
-                 (emacspeak-personality-plist-face-p props) ) ;;; simple minded for now
+                 (emacspeak-personality-plist-face-p props)) ;;; simple minded for now
         (put-text-property start end
                            'personality nil object)))))
 
@@ -450,43 +385,23 @@ Append means place corresponding personality at the end."
 
 (defadvice overlay-put (after emacspeak-personality  pre act)
   "Used by emacspeak to augment font lock."
-  (let ((overlay (ad-get-arg 0))
-        (prop (ad-get-arg 1))
-        (value (ad-get-arg 2))
-        (voice nil))
-    (when (and
-           (or (eq prop 'face)
-               (and (eq prop 'category)
-                    (get value 'face)))
-           (integer-or-marker-p (overlay-start overlay))
-           (integer-or-marker-p (overlay-end overlay)))
-      (and (eq prop 'category)
-           (setq value (get value 'face)))
-      (cond
-       ((symbolp value)
-        (setq voice (voice-setup-get-voice-for-face   value)))
-       ((listp value)
-        (setq voice
-              (delq nil
-                    (mapcar
-                     #'voice-setup-get-voice-for-face value))))
-       (t (message "Got %s" value)))
-      (when voice
-        (and emacspeak-personality-voiceify-overlays
-             (funcall emacspeak-personality-voiceify-overlays
-                      (overlay-start overlay)
-                      (overlay-end overlay)
-                      voice))
-        (overlay-put overlay 'personality voice))
-      (when (and emacspeak-personality-show-unmapped-faces
-                 (not voice))
-        (cond
-         ((listp value)
-          (mapcar #'(lambda (v)
-                      (puthash  v t emacspeak-personality-unmapped-faces))
-                  value))
-         (t (puthash  value t
-                      emacspeak-personality-unmapped-faces)))))))
+  (when emacspeak-personality-voiceify-overlays
+    (let ((overlay (ad-get-arg 0))
+          (prop (ad-get-arg 1))
+          (value (ad-get-arg 2))
+          (voice nil))
+                                        ; special case buttons
+      (when (and
+             (or (eq prop 'face)
+                 (and (eq prop 'category) (get value 'face)))
+             (integer-or-marker-p (overlay-start overlay))
+             (integer-or-marker-p (overlay-end overlay)))
+        (and (eq prop 'category) (setq value (get value 'face)))
+        (setq voice (ems-get-voice-for-face value))
+        (when voice
+          (funcall emacspeak-personality-voiceify-overlays
+                   (overlay-start overlay) (overlay-end overlay)
+                   voice))))))
 
 (defadvice move-overlay (before emacspeak-personality  pre act)
   "Used by emacspeak to augment font lock."
@@ -507,25 +422,13 @@ Append means place corresponding personality at the end."
       (funcall emacspeak-personality-voiceify-overlays
                beg end voice))))
 
-;;}}}
-;;{{{ silence font-lock's error messages
-
-(loop for f in
-      '(font-lock-default-fontify-region
-        font-lock-default-fontify-buffer)
-      do
-      (eval
-       `(defadvice ,f (around emacspeak pre act comp)
-          "Silence auditory feedback from redisplay errors."
-          (ems-with-errors-silenced ad-do-it))))
-
 ;;}}}
 (provide 'emacspeak-personality )
 ;;{{{ end of file
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
