@@ -1,5 +1,5 @@
 ;;; emacspeak-re-builder.el --- speech-enable re-builder
-;;; $Id: emacspeak-re-builder.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; $Id: emacspeak-re-builder.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:   extension to speech enable re-builder
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -66,18 +66,18 @@
 
 (defadvice  re-builder (after emacspeak pre act comp)
   "Speak status information."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
 
 (defadvice reb-quit (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 
 (defadvice reb-next-match (after emacspeak pre act comp)
   "Speak matched line."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (save-excursion
       (set-buffer reb-target-buffer)
       (emacspeak-speak-line)
@@ -85,7 +85,7 @@
 
 (defadvice reb-prev-match (after emacspeak pre act comp)
   "Speak matched line."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (save-excursion
       (set-buffer reb-target-buffer)
       (emacspeak-speak-line)
@@ -93,7 +93,7 @@
 
 (defadvice reb-toggle-case (after emacspeak pre act comp)
   "Provide spoken feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (save-excursion
       (set-buffer reb-target-buffer)
       (emacspeak-auditory-icon
@@ -101,16 +101,16 @@
 
 (defadvice reb-copy (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'yank-object)))
 
 (defun reb-enter-subexp-mode (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)))
 (defadvice reb-quit-subexp-mode (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 
 ;;}}}
@@ -119,7 +119,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
