@@ -1,5 +1,5 @@
 ;;; emacspeak-ruby.el --- Speech enable Ruby Mode 
-;;; $Id: emacspeak-ruby.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; $Id: emacspeak-ruby.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; DescriptionEmacspeak extensions for Ruby mode
 ;;; Keywords:emacspeak, audio interface to emacs Ruby
@@ -66,7 +66,7 @@
       (eval
        `(defadvice ,command (after emacspeak pre act comp)
           "Provide auditory feedback."
-          (when (interactive-p)
+          (when (ems-interactive-p )
             (emacspeak-speak-line)
             (emacspeak-auditory-icon 'large-movement)))))
 
@@ -75,7 +75,7 @@
 
 (defadvice ruby-insert-end (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (save-excursion
       (ruby-beginning-of-block)
@@ -83,24 +83,26 @@
 
 (defadvice ruby-reindent-then-newline-and-indent (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)))
 
 (defadvice ruby-indent-line (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)))
 
 (defadvice ruby-indent-exp (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'fill-object)))
-
-(defadvice ruby-electric-brace (after emacspeak pre act comp)
-  "Speak what you inserted.
-Cue electric insertion with a tone."
-  (when (interactive-p)
+(unless (and (boundp 'post-self-insert-hook)
+             post-self-insert-hook
+             (memq 'emacspeak-post-self-insert-hook post-self-insert-hook))
+  (defadvice ruby-electric-brace (after emacspeak pre act comp)
+    "Speak what you inserted.
+Cue electric insertion with a tone.")
+  (when (ems-interactive-p )
     (let ((emacspeak-speak-messages nil))
       (emacspeak-speak-this-char last-input-event)
       (dtk-tone 800 50 t))))
@@ -119,7 +121,7 @@ Cue electric insertion with a tone."
       (eval
        `(defadvice ,command (after emacspeak pre act comp)
           "Provide auditory feedback."
-          (when (interactive-p)
+          (when (ems-interactive-p )
             (emacspeak-auditory-icon 'select-object)
             (emacspeak-speak-line)))))
 
@@ -130,7 +132,7 @@ Cue electric insertion with a tone."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
