@@ -1,5 +1,5 @@
 ;;; emacspeak-ses.el --- Speech-enable ses spread-sheet
-;;; $Id: emacspeak-ses.el 7378 2011-11-10 17:34:32Z tv.raman.tv $
+;;; $Id: emacspeak-ses.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak front-end for SES 
 ;;; Keywords: Emacspeak, ses 
@@ -51,18 +51,18 @@
 ;;; Code:
 (require 'emacspeak-preamble)
 (require 'emacspeak-redefine)
-
 ;;}}}
+
 ;;{{{ SES Accessors:
 
 ;;; these are defined as macros in ses.el 
-;;; and are cloned here as defsubst forms for now.
+;;; and are cloned here as defsubst forms 
 
 (defsubst emacspeak-ses-get-cell (row col)
   "Return the cell structure that stores information about cell
   (ROW,COL)."
-  (declare (special cells))
-  (aref (aref cells row) col))
+  (declare (special ses--cells))
+  (aref (aref ses--cells row) col))
 
 (defsubst emacspeak-ses-cell-symbol (row &optional col)
   "From a CELL or a pair (ROW,COL), get the symbol that names the local-variable holding its value.  (0,0) => A1."
@@ -71,7 +71,6 @@
 (defsubst emacspeak-ses-cell-formula (row &optional col)
   "From a CELL or a pair (ROW,COL), get the function that computes its value."
   (aref  (if col (emacspeak-ses-get-cell  row  col) row) 1))
-
 (defsubst emacspeak-ses-cell-value (row &optional col)
   "From a CELL or a pair (ROW,COL), get the current value for that cell."
   (symbol-value (emacspeak-ses-cell-symbol row col)))
@@ -81,6 +80,24 @@
 is nil if SYM is not a symbol that names a cell."
   (and (symbolp  sym) (get  sym 'ses-cell)))
 
+(defsubst emacspeak-ses-cell-printer (row &optional col)
+  "From a CELL or a pair (ROW,COL), get the function that prints its value."
+  (aref (if col (ses-get-cell row col) row) 2))
+(defsubst emacspeak-ses-cell-property-get (property-name row &optional col)
+  "Get property named PROPERTY-NAME from a CELL or a pair (ROWCOL).
+
+When COL is omitted CELL=ROW is a cell object.  When COL is
+present ROW and COL are the integer coordinates of the cell of
+interest."
+  (declare (debug t))
+  (ses-cell-property-get-fun
+   property-name
+   (if col (ses-get-cell row col) row)))
+
+(defsubst emacspeak-ses-col-printer (col)
+  "Return the default printer for column COL."
+  (declare (special ses--col-printers))
+  (aref ses--col-printers col)) ;;}}}
 ;;}}}
 ;;{{{ emacspeak ses accessors 
 
@@ -88,9 +105,7 @@ is nil if SYM is not a symbol that names a cell."
 ;;;earlier helpers by Emacspeak.
 (defsubst emacspeak-ses-current-cell-symbol ()
   "Return symbol for current cell."
-  (declare (special curcell))
-  (or (get-text-property (point) 'intangible)
-      curcell))
+  (get-text-property (point) 'intangible))
 
 (defsubst emacspeak-ses-current-cell-value ()
   "Return current cell value."
@@ -112,7 +127,7 @@ is nil if SYM is not a symbol that names a cell."
   (interactive
    (list
     (read-minibuffer "Cell: ")))
-  (message
+  (dtk-speak
    (format "%s: %s"
            cell-name
            (emacspeak-ses-get-cell-value-by-name cell-name))))
@@ -179,18 +194,30 @@ is nil if SYM is not a symbol that names a cell."
 
 (defadvice ses-forward-or-insert (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
+    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-ses-summarize-current-cell)))
+
+(defadvice ses-recalculate-cell (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (ems-interactive-p )
+    (emacspeak-ses-summarize-current-cell)
+    (emacspeak-auditory-icon 'task-done)))
+
+(defadvice ses-jump (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-ses-summarize-current-cell)))
 
 ;;}}}
-                                        ;(emacspeak-ses-setup)
+(emacspeak-ses-setup)
 (provide 'emacspeak-ses)
 ;;{{{ end of file
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
