@@ -1,5 +1,5 @@
 ;;; emacspeak-table-ui.el --- Emacspeak's current notion of an ideal table UI
-;;; $Id: emacspeak-table-ui.el 7733 2012-05-03 02:12:31Z tv.raman.tv $
+;;; $Id: emacspeak-table-ui.el 8064 2013-01-05 03:13:39Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Emacspeak table handling module
 ;;; Keywords:emacspeak, audio interface to emacs tables are structured
@@ -208,8 +208,7 @@ specifies the filter"
   "Bring visual display in sync with internal representation"
   (declare (special emacspeak-table positions))
   (let ((row (emacspeak-table-current-row emacspeak-table))
-        (column (emacspeak-table-current-column
-                 emacspeak-table))
+        (column (emacspeak-table-current-column emacspeak-table))
         (width (frame-width)))
     (goto-char
      (or
@@ -246,7 +245,7 @@ specifies the filter"
   (interactive)
   (declare (special emacspeak-table ))
   (and (boundp 'emacspeak-table)
-       (message (emacspeak-table-current-element emacspeak-table))))
+       (dtk-speak-and-echo (emacspeak-table-current-element emacspeak-table))))
 
 (defun emacspeak-table-speak-row-header-and-element ()
   "Speak  row header and table element"
@@ -258,7 +257,7 @@ specifies the filter"
                            (emacspeak-table-row-header-element emacspeak-table
                                                                (emacspeak-table-current-row emacspeak-table )))))
          (put-text-property 0 (length head) 'face 'italic head)
-         (message
+         (dtk-speak-and-echo
           (concat head
                   (format " %s"
                           (emacspeak-table-current-element emacspeak-table)))))))
@@ -274,7 +273,7 @@ specifies the filter"
                                                                   (emacspeak-table-current-column emacspeak-table )))))
          (put-text-property 0 (length head)
                             'face 'italic head)
-         (message
+         (dtk-speak-and-echo
           (concat head
                   (format " %s"
                           (emacspeak-table-current-element emacspeak-table)))))))
@@ -299,7 +298,7 @@ specifies the filter"
          (put-text-property 0 (length column-head)
                             'personality
                             emacspeak-table-column-header-personality column-head)
-         (message
+         (dtk-speak-and-echo
           (concat row-head" "  column-head
                   (format " %s"
                           (emacspeak-table-current-element
@@ -358,7 +357,7 @@ Optional prefix arg prompts for a new filter."
     (emacspeak-table-ui-filter-set
      (emacspeak-table-ui-generate-key)
      emacspeak-table-speak-row-filter))
-  (message
+  (dtk-speak-and-echo
    (mapconcat
     #'(lambda (token)
         (let ((value nil))
@@ -422,7 +421,7 @@ Optional prefix arg prompts for a new filter."
                 (not prefix))
     (setq emacspeak-table-speak-column-filter
           (read-minibuffer "Specify column filter as a list: " "(")))
-  (message
+  (dtk-speak-and-echo
    (mapconcat
     #'(lambda (token)
         (cond
@@ -731,7 +730,7 @@ browsing table elements"
   "Function to call when automatically speaking table elements.")
 
 (make-variable-buffer-local 'emacspeak-table-speak-element)
-
+;;;###autoload
 (defun emacspeak-table-next-row (&optional count)
   "Move to the next row if possible"
   (interactive "p")
@@ -743,7 +742,7 @@ browsing table elements"
    (t (emacspeak-table-move-down emacspeak-table count )
       (emacspeak-table-synchronize-display)
       (funcall emacspeak-table-speak-element))))
-
+;;;###autoload
 (defun emacspeak-table-previous-row (&optional count)
   "Move to the previous row if possible"
   (interactive "p")
@@ -755,7 +754,7 @@ browsing table elements"
    (t (emacspeak-table-move-up emacspeak-table count )
       (emacspeak-table-synchronize-display)
       (funcall emacspeak-table-speak-element))))
-
+;;;###autoload
 (defun emacspeak-table-next-column (&optional count)
   "Move to the next column if possible"
   (interactive "p")
@@ -767,7 +766,7 @@ browsing table elements"
    (t(emacspeak-table-move-right emacspeak-table count )
      (emacspeak-table-synchronize-display)
      (funcall emacspeak-table-speak-element))))
-
+;;;###autoload
 (defun emacspeak-table-previous-column (&optional count)
   "Move to the previous column  if possible"
   (interactive "p")
@@ -946,7 +945,7 @@ match, makes the matching row or column current."
   (declare (special emacspeak-table ))
   (when (boundp 'emacspeak-table)
     (kill-new  (emacspeak-table-current-element emacspeak-table))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-auditory-icon 'delete-object)
       (message "Copied element to kill ring"))))
 
@@ -957,7 +956,7 @@ match, makes the matching row or column current."
   (when  (boundp 'emacspeak-table)
     (set-register register (emacspeak-table-current-element
                             emacspeak-table))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-auditory-icon 'select-object)
       (message "Copied element to register %c" register))))
 
