@@ -1,5 +1,5 @@
 ;;; emacspeak-url-template.el --- Create library of URI templates
-;;; $Id: emacspeak-url-template.el 7570 2012-03-11 16:20:35Z tv.raman.tv $
+;;; $Id: emacspeak-url-template.el 8272 2013-03-29 15:39:21Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:   Implement library of URI templates
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -42,10 +42,10 @@
 
 ;;; Commentary:
 
-;;; It is often useful to have ``parameterized hot list entries''
+;;; It is often useful to have ``parametrized hot list entries''
 ;;; i.e., hotlist entries  that are ``templates'' for the
 ;;; actual URL.
-;;; The user provides values for the parameterized portions
+;;; The user provides values for the parametrized portions
 ;;; of the URL e.g. the date.
 ;;; See @xref{URL Templates}, for details on the URL templates
 ;;; that are presently defined.
@@ -491,9 +491,9 @@ dont-url-encode if true then url arguments are not url-encoded "
  nil
  "Display financial market summary."
  #'(lambda (url)
-     (emacspeak-we-extract-id-list-text
-      (list "mktsumm" "sfe-mktsumm" )
-      url 'speak)))
+     (let ((w3-auto-image-alt nil))
+       (emacspeak-we-extract-by-class
+        "id-summary-chart" url 'speak))))
 
 ;;}}}
 ;;{{{ google CSE and Google Reader:
@@ -1237,6 +1237,14 @@ from English to German.")
      (emacspeak-webutils-without-xsl
       (browse-url url))))
 
+(emacspeak-url-template-define
+ "IToRSS"
+ "http://feedflipper.net/convert.php?feed=%s"
+ (list "ITunes URL: ")
+ nil
+ "Pull RSS  feed corresponding to an ITunes Podcast."
+ 'emacspeak-webutils-rss-display)
+
 ;;}}}
 ;;{{{  cnet news
 
@@ -1554,7 +1562,7 @@ name of the list.")
                                        "%m/%d") )
 
 (emacspeak-url-template-define
- "CNN Tecnology "
+ "CNN technology "
  "http://www.cnn.com/TECH/"
  nil
  #'(lambda nil
