@@ -1,5 +1,5 @@
 ;;; emacspeak-vm.el --- Speech enable VM -- A powerful mail agent (and the one I use)
-;;; $Id: emacspeak-vm.el 7323 2011-10-26 00:50:39Z tv.raman.tv $
+;;; $Id: emacspeak-vm.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech enhance vm
 ;;; Keywords: Emacspeak, VM, Email, Spoken Output, Voice annotations
@@ -165,23 +165,20 @@ Note that some badly formed mime messages  cause trouble."
                     emacspeak-vm-headers-strip-octals
                     emacspeak-vm-user-full-name emacspeak-vm-user-login-name))
   (when vm-message-pointer
-    (dtk-stop)
-    (let*  ((dtk-stop-immediately t )
-            (message (car vm-message-pointer ))
+    (let*  ((message (car vm-message-pointer ))
             (number (emacspeak-vm-number-of  message))
-            (from(or (vm-su-full-name message)
-                     (vm-su-from message )))
+            (from
+             (or (vm-su-full-name message) (vm-su-from message )))
             (subject (vm-su-subject message ))
-            (to(or (vm-su-to-names message)
-                   (vm-su-to message )))
-            (self-p (or
-                     (string-match emacspeak-vm-user-full-name to)
-                     (string-match  (user-login-name) to)
-                     (string-match
-                      (format "%s@%s" (user-login-name) smtpmail-local-domain)
-                      to)))
-            (lines (vm-su-line-count message))
-            (summary nil))
+            (to
+             (or (vm-su-to-names message) (vm-su-to message )))
+            (self-p
+             (or (string-match emacspeak-vm-user-full-name to)
+                 (string-match  (user-login-name) to)
+                 (string-match (format "%s@%s" (user-login-name)
+                                       smtpmail-local-domain)
+                               to)))
+            (lines (vm-su-line-count message)))
       (dtk-speak
        (vm-decode-mime-encoded-words-in-string
         (format "%s %s %s   %s %s "
@@ -264,7 +261,7 @@ that has been forwarded multiple times."
 (defadvice vm-scroll-forward (after emacspeak pre act)
   "Produce auditory feedback.
 Then speak the screenful. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (save-excursion
       (let ((start  (point ))
@@ -275,7 +272,7 @@ Then speak the screenful. "
 (defadvice vm-scroll-backward (after emacspeak pre act)
   "Produce auditory feedback.
 Then speak the screenful. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (save-excursion
       (let ((start  (point ))
@@ -306,18 +303,18 @@ Then speak the screenful. "
 
 (defadvice vm-delete-message (after emacspeak pre act)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (message "Message discarded.")))
 
 (defadvice vm-undelete-message (after emacspeak pre act)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Message recovered.")))
 
 (defadvice vm-kill-subject (after emacspeak pre act)
   "Provide auditory feedback. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (call-interactively 'vm-next-message)))
 
@@ -326,7 +323,7 @@ Then speak the screenful. "
 
 (defadvice vm-forward-message (around emacspeak pre act)
   "Provide aural feedback."
-  (if (interactive-p)
+  (if (ems-interactive-p )
       (let ((dtk-stop-immediately nil))
         (message "Forwarding message")
         ad-do-it
@@ -336,39 +333,39 @@ Then speak the screenful. "
 
 (defadvice vm-reply (after emacspeak pre act)
   "Provide aural feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-mode-line)))
 
 (defadvice vm-followup (after emacspeak pre act)
   "Provide aural feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Folluwing up")
     (emacspeak-speak-mode-line)))
 
 (defadvice vm-reply-include-text (after emacspeak pre act)
   "Provide aural feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-mode-line )))
 
 (defadvice vm-followup-include-text (after emacspeak pre act)
   "Provide aural feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Following up")
     (emacspeak-speak-mode-line )))
 (defadvice vm-mail-send (after emacspeak pre act comp)
   "Provide auditory context"
-  (when  (interactive-p)
+  (when  (ems-interactive-p )
     (emacspeak-speak-mode-line)
     (emacspeak-auditory-icon 'close-object)))
 
 (defadvice vm-mail-send-and-exit (after emacspeak pre act comp)
   "Provide auditory context"
-  (when  (interactive-p)
+  (when  (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 
 (defadvice vm-mail (after emacspeak pre act)
   "Provide aural feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((dtk-stop-immediately nil))
       (message "Composing a message")
       (emacspeak-speak-line ))))
@@ -378,7 +375,7 @@ Then speak the screenful. "
 
 (defadvice vm-quit (after emacspeak pre act )
   "Provide an auditory icon if requested"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
@@ -414,7 +411,7 @@ Then speak the screenful. "
   "Provide auditory feedback"
   (declare (special vm-message-pointer))
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((orig (point)))
       ad-do-it
       (cond
@@ -429,7 +426,7 @@ Then speak the screenful. "
   "Provide auditory feedback"
   (declare (special vm-message-pointer))
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((orig (point)))
       ad-do-it
       (cond
@@ -455,7 +452,7 @@ Then speak the screenful. "
   "Provide auditory feedback.
 Leave point at front of decoded attachment."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((orig (point )))
       ad-do-it
       (goto-char orig)
@@ -522,7 +519,7 @@ Leave point at front of decoded attachment."
 ;;{{{ advice button motion
 (defadvice vm-next-button (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-text-range  'w3-hyperlink-info)))
 
@@ -728,7 +725,7 @@ text using wvText."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
