@@ -1,5 +1,5 @@
 ;;; emacspeak-xslt.el --- Implements Emacspeak  xslt transform engine
-;;; $Id: emacspeak-xslt.el 7668 2012-04-07 17:07:15Z tv.raman.tv $
+;;; $Id: emacspeak-xslt.el 8276 2013-03-30 15:19:30Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  xslt transformation routines
 ;;; Keywords: Emacspeak,  Audio Desktop XSLT
@@ -92,7 +92,7 @@
 
 ;;;###autoload
 (defcustom emacspeak-xslt-options
-  "--html --nonet --novalid"
+  "--html --nonet --novalid --encoding utf-8"
   "Options passed to xsltproc."
   :type 'string
   :group 'emacspeak-xslt)
@@ -110,8 +110,6 @@ This is useful when handling bad HTML."
 
 ;;}}}
 ;;{{{ Functions:
-(defvar emacspeak-xslt-last-command nil
-  "Cache last xsltproc command we exectued.")
 
 ;;;###autoload
 (defun emacspeak-xslt-region (xsl start end &optional params no-comment)
@@ -119,7 +117,6 @@ This is useful when handling bad HTML."
 the result.  This uses XSLT processor xsltproc available as
 part of the libxslt package."
   (declare (special emacspeak-xslt-program emacspeak-xslt-options
-                    emacspeak-xslt-last-command
                     emacspeak-xslt-keep-errors modification-flag ))
   (let ((command nil)
         (parameters (when params
@@ -141,7 +138,6 @@ part of the libxslt package."
            (or parameters "")
            xsl
            (unless  emacspeak-xslt-keep-errors " 2>/dev/null ")))
-    (setq emacspeak-xslt-last-command command)
     (shell-command-on-region
      start end
      command
@@ -366,7 +362,7 @@ part of the libxslt package."
            (cons "base"
                  (format "\"'%s'\""
                          url))))))
-    (when (interactive-p) (emacspeak-webutils-autospeak))
+    (when (ems-interactive-p ) (emacspeak-webutils-autospeak))
     (save-excursion
       (set-buffer src-buffer)
       (when unescape-charent
@@ -401,7 +397,7 @@ part of the libxslt package."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
