@@ -1,5 +1,5 @@
 ;;; emacspeak.el --- Emacspeak -- The Complete Audio Desktop
-;;; $Id: emacspeak.el 7695 2012-04-18 15:34:29Z tv.raman.tv $
+;;; $Id: emacspeak.el 8344 2013-05-11 16:15:32Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak: A speech interface to Emacs
 ;;; Keywords: Emacspeak, Speech, Dectalk,
@@ -52,7 +52,6 @@
 
 (require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
-(require 'backquote)
 (require 'emacspeak-preamble)
 (require 'emacspeak-sounds)
 
@@ -169,6 +168,7 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "cus-edit" 'emacspeak-custom)
 (emacspeak-do-package-setup "damlite" 'emacspeak-damlite)
 (emacspeak-do-package-setup "desktop" 'emacspeak-desktop )
+(emacspeak-do-package-setup "diff-mode" 'emacspeak-diff-mode )
 (emacspeak-do-package-setup "dired" 'emacspeak-dired )
 (emacspeak-do-package-setup "dismal" 'emacspeak-dismal)
 (emacspeak-do-package-setup "dictation" 'emacspeak-dictation)
@@ -184,6 +184,7 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "erc" 'emacspeak-erc)
 (emacspeak-do-package-setup "eshell" 'emacspeak-eshell)
 (emacspeak-do-package-setup "ess" 'emacspeak-ess)
+(emacspeak-do-package-setup "eclim" 'emacspeak-eclim)
 (emacspeak-do-package-setup "enriched" 'emacspeak-enriched)
 (emacspeak-do-package-setup "facemenu" 'emacspeak-facemenu)
 (emacspeak-do-package-setup "find-dired" 'emacspeak-find-dired)
@@ -193,6 +194,7 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "folding" 'emacspeak-folding)
 (emacspeak-do-package-setup "forms" 'emacspeak-forms)
 (emacspeak-do-package-setup "generic" 'emacspeak-generic)
+(emacspeak-do-package-setup "gtags" 'emacspeak-gtags)
 (emacspeak-do-package-setup "gnus" 'emacspeak-gnus)
 (emacspeak-do-package-setup "gnuplot" 'emacspeak-gnuplot)
 (emacspeak-do-package-setup "gomoku" 'emacspeak-gomoku)
@@ -209,6 +211,8 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "jabber" 'emacspeak-jabber)
 (emacspeak-do-package-setup "jde" 'emacspeak-jde)
 (emacspeak-do-package-setup "js2" 'emacspeak-js2)
+(emacspeak-do-package-setup "js2-mode" 'emacspeak-js2)
+(emacspeak-do-package-setup "kite" 'emacspeak-kite)
 (emacspeak-do-package-setup "kmacro" 'emacspeak-kmacro)
 (emacspeak-do-package-setup "magit" 'emacspeak-magit)
 (emacspeak-do-package-setup "make-mode" 'emacspeak-make-mode)
@@ -232,7 +236,7 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "pcl-cvs" 'emacspeak-pcl-cvs)
 (emacspeak-do-package-setup "pcvs" 'emacspeak-pcl-cvs)
 (emacspeak-do-package-setup "psgml" 'emacspeak-psgml)
-(emacspeak-do-package-setup "python-mode" 'emacspeak-python)
+(emacspeak-do-package-setup "python" 'emacspeak-python)
 (emacspeak-do-package-setup "python-mode" 'emacspeak-py)
 (emacspeak-do-package-setup "re-builder" 'emacspeak-re-builder)
 (emacspeak-do-package-setup "reftex" 'emacspeak-reftex)
@@ -295,8 +299,7 @@ speech-enabling extensions."
   (when
       (yes-or-no-p "Are you sure you want to submit a bug report? ")
     (let (
-          (vars '(window-system
-                  window-system-version
+          (vars '(
                   emacs-version
                   system-type
                   emacspeak-version  dtk-program
@@ -384,7 +387,8 @@ sets punctuation mode to all, activates the dictionary and turns on split caps."
          'tcl-mode-hook
          'html-helper-mode-hook
          'scheme-mode-hook
-         'dired-mode-hook)))
+         'dired-mode-hook
+         'python-mode-hook)))
 
 ;;}}}
 ;;{{{ set up after-init-hook to fix interactive functions
@@ -439,21 +443,17 @@ term package that comes with emacs-19.29 and later.
 See the online documentation for individual commands and
 functions for details.   "
   (interactive)
-  (declare (special mark-even-if-inactive
-                    emacspeak-pronounce-load-pronunciations-on-startup
+  (declare (special emacspeak-pronounce-load-pronunciations-on-startup
                     emacspeak-pronounce-dictionaries-file
-                    default-enable-multibyte-characters
                     emacspeak-play-program
                     emacspeak-sounds-directory))
-;;; fixes transient mark mode in emacspeak
-  (setq mark-even-if-inactive t)
   (emacspeak-export-environment)
   (require 'emacspeak-personality)
   (dtk-initialize)
   (tts-configure-synthesis-setup)
   (require 'emacspeak-redefine)
-  (require 'emacspeak-advice)
   (require 'emacspeak-replace)
+  (require 'emacspeak-advice)
   (emacspeak-play-startup-icon)
   (emacspeak-sounds-define-theme-if-necessary emacspeak-sounds-default-theme)
   (when emacspeak-pronounce-load-pronunciations-on-startup
@@ -483,7 +483,7 @@ functions for details.   "
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
