@@ -2,24 +2,25 @@
 ;;
 ;;; Code:
 
+(put 'gskeleton 'custom-loads '(gskeleton))
 (put 'ghealth 'custom-loads '(ghealth))
 (put 'g-auth 'custom-loads '(g-auth))
-(put 'gfinance 'custom-loads '(gfinance))
 (put 'gphoto 'custom-loads '(gphoto))
-(put 'gcontacts 'custom-loads '(gcontacts))
 (put 'gtube 'custom-loads '(gtube))
-(put 'gblogger 'custom-loads '(gblogger))
 (put 'gwis 'custom-loads '(gwis))
-(put 'gnotebook 'custom-loads '(gnotebook))
-(put 'gweb 'custom-loads '(gweb))
+(put 'gmaps 'custom-loads '(gmaps))
+(put 'gweb 'custom-loads '(gmaps))
 (put 'gbooks 'custom-loads '(gbooks))
-(put 'applications 'custom-loads '(g))
+(put 'gnotebook 'custom-loads '(gnotebook))
+(put 'gcontacts 'custom-loads '(gcontacts))
 (put 'gdocs 'custom-loads '(gdocs))
+(put 'gfinance 'custom-loads '(gfinance))
+(put 'applications 'custom-loads '(g))
 (put 'gfeeds 'custom-loads '(gfeeds))
 (put 'gcal 'custom-loads '(gcal))
 (put 'gsheet 'custom-loads '(gsheet))
-(put 'g 'custom-loads '(g-utils g-auth gblogger gbooks gcal gcontacts gdocs gfeeds gfinance ghealth gnotebook gphoto greader gsheet gskeleton gtube gweb))
-(put 'gskeleton 'custom-loads '(gskeleton))
+(put 'g 'custom-loads '(g-utils g-auth gblogger gbooks gcal gcontacts gdocs gfeeds gfinance ghealth gmaps gnotebook gphoto greader gsheet gskeleton gtube gweb))
+(put 'gblogger 'custom-loads '(gblogger))
 (put 'greader 'custom-loads '(greader))
 ;; These are for handling :version.  We need to have a minimum of
 ;; information so `customize-changed-options' could do its job.
